==> broadleaf-framework-1.5.3-GA-sources.jar: org/broadleafcommerce/core/offer/service/discount/domain/PromotableCandidateFulfillmentGroupOffer.java <==
/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.broadleafcommerce.core.offer.service.discount.domain;

import java.util.HashMap;
import java.util.List;

import org.broadleafcommerce.core.offer.domain.CandidateFulfillmentGroupOffer;
import org.broadleafcommerce.core.offer.domain.Offer;
import org.broadleafcommerce.core.offer.domain.OfferItemCriteria;
import org.broadleafcommerce.money.Money;

public interface PromotableCandidateFulfillmentGroupOffer {

	public HashMap<OfferItemCriteria, List<PromotableOrderItem>> getCandidateQualifiersMap();

	public void setCandidateQualifiersMap(HashMap<OfferItemCriteria, List<PromotableOrderItem>> candidateItemsMap);

	public void computeDiscountedPriceAndAmount();

	public void reset();

	public CandidateFulfillmentGroupOffer getDelegate();

	public Money getDiscountedPrice();
	
	public Offer getOffer();
	
	public PromotableFulfillmentGroup getFulfillmentGroup();

    public Money getDiscountedAmount();
}

==> broadleaf-framework-1.6.0-GA-sources.jar: org/broadleafcommerce/core/offer/service/discount/domain/PromotableCandidateFulfillmentGroupOffer.java <==
/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.broadleafcommerce.core.offer.service.discount.domain;

import java.util.HashMap;
import java.util.List;

import org.broadleafcommerce.core.offer.domain.CandidateFulfillmentGroupOffer;
import org.broadleafcommerce.core.offer.domain.Offer;
import org.broadleafcommerce.core.offer.domain.OfferItemCriteria;
import org.broadleafcommerce.common.money.Money;

public interface PromotableCandidateFulfillmentGroupOffer {

	public HashMap<OfferItemCriteria, List<PromotableOrderItem>> getCandidateQualifiersMap();

	public void setCandidateQualifiersMap(HashMap<OfferItemCriteria, List<PromotableOrderItem>> candidateItemsMap);

	public void computeDiscountedPriceAndAmount();

	public void reset();

	public CandidateFulfillmentGroupOffer getDelegate();

	public Money getDiscountedPrice();
	
	public Offer getOffer();
	
	public PromotableFulfillmentGroup getFulfillmentGroup();

    public Money getDiscountedAmount();
}
